@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009, 2010, 2011, 2012 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2009, 2010, 2011, 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ except ImportError, ex:
     utils.enhance_import_error(ex, 'Python Imaging Library', 'python-imaging', 'http://www.pythonware.com/products/pil/')
     raise
 else:
-    # Gamera still expects that PIL can be imported as Image
+    # Gamera (<< 3.4.0) still expects that PIL can be imported as Image
     sys.modules['Image'] = PIL
 
 try:
@@ -90,6 +90,8 @@ def _load_methods():
         from gamera.plugins.binarization import white_rohrer_threshold
         if has_version(3, 3, 1):
             from gamera.plugins.binarization import shading_subtraction
+        if has_version(3, 4, 0):
+            from gamera.plugins.binarization import brink_threshold
     methods = {}
     for name, plugin in vars(_methods).items():
         if name.startswith('_'):
@@ -114,7 +116,7 @@ def to_pil_1bpp(image):
 
 def _decref(o):
     '''
-    Forcibly set refcount of the object to 1.
+    Forcibly decrease refcount of the object by 1.
     '''
     libc = ctypes.cdll.LoadLibrary(None)
     memmove = libc.memmove
